@@ -167,7 +167,7 @@ class DatasetDefCommand(IExecutableCommand):
                         iss = prepare_dataframe_after_external_read(ds, df, name)
                         issues.extend(iss)
                         # Everything ok? Store the dataframe!
-                        if len(iss) == 0:
+                        if not any_error_issue(iss):
                             ds.data = df
 
         if not error:
@@ -187,6 +187,8 @@ class DatasetDefCommand(IExecutableCommand):
                             dsd_concept_data_type = c.attributes["_datatype"]
                             if dsd_concept_data_type.lower() == "string" and not c.is_measure:  # Freely defined dimension
                                 cl = df[cid[c.code]].unique().tolist()
+                                # Filter "nan", with c == c (a Python idiom achieving this...)
+                                cl = [c if c == c else "" for c in cl]
                                 c.code_list = CodeList.construct(
                                     c.code, c.code, [""],
                                     codes=[CodeImmutable(c, c, "", []) for c in cl]
