@@ -1,3 +1,4 @@
+import ast
 import logging
 
 from sqlalchemy.orm import class_mapper
@@ -172,8 +173,6 @@ def serialize_state(state: State):
             state2.set("_glb_idx", tmp, ns)
         # lcia_methods = state2.get("_lcia_methods", ns)
         # if lcia_methods:
-        #     # TODO Save as CSV. Deserialize should put into a PartialRetrievalDictionary again
-        #
         #     tmp = lcia_methods.to_pickable()
         #     state2.set("_lcia_methods", tmp, ns)
         _, _, _, datasets, _ = get_case_study_registry_objects(state, ns)
@@ -241,7 +240,10 @@ def deserialize_state(st: str, state_version: int = MODEL_VERSION):
 
     # Iterate all namespaces
     for ns in state.list_namespaces():
-        # lcia_methods = state.get("_lcia_methods", ns)
+        lcia_methods = state.get("_lcia_methods", ns)
+        if lcia_methods:
+            _ = {ast.literal_eval(k): v for k,v in lcia_methods.items()}
+            state.set("_lcia_methods", _, ns)
         # if isinstance(lcia_methods, dict):
         #     lcia_methods = PartialRetrievalDictionary().from_pickable(lcia_methods)
         #     state.set("_lcia_methods", lcia_methods)
